@@ -6,4 +6,4 @@ Copyright (c) 2020, ETH Zurich, Computer Engineering Group (TEC)
 from ._version import __version__
 from .flocklab import Flocklab
 from .visualization import visualizeFlocklabTrace
-from .xmlconfig import FlocklabXmlConfig, GeneralConf, TargetConf, SerialConf, GpioTracingConf, GpioActuationConf, PowerProfilingConf, ImageConf, DebugConf
+from .xmlconfig import FlocklabXmlConfig, GeneralConf, TargetConf, SerialConf, GpioTracingConf, GpioActuationConf, PowerProfilingConf, EmbeddedImageConf, DebugConf
