@@ -8,7 +8,7 @@ import os
 import requests
 import json
 import re
-import datetime
+from datetime import datetime
 import argparse
 import tarfile
 from collections import OrderedDict
@@ -31,6 +31,7 @@ def main():
     parser.add_argument('-c', '--create', metavar='<testconfig.xml>', help='create / schedule new test')
     parser.add_argument('-a', '--abort', metavar='<testid>', help='abort test')
     parser.add_argument('-d', '--delete', metavar='<testid>', help='delete test')
+    parser.add_argument('-i', '--info', metavar='<testid>', help='get test info')
     parser.add_argument('-g', '--get', metavar='<testid>', help='get test results (via https)')
     parser.add_argument('-f', '--fetch', metavar='<testid>', help='fetch test results (via webdav) [NOT IMPLEMENTED YET!]')
     parser.add_argument('-o', '--observers', metavar='<platform>', help='get a list of the currently available (online) observers')
@@ -45,11 +46,13 @@ def main():
     if args.validate is not None:
         print(fl.xmlValidate(args.validate))
     elif args.create is not None:
-        print(fl.createTest(args.create))
+        print(fl.createTestWithInfo(args.create))
     elif args.abort is not None:
         print(fl.abortTest(args.abort))
     elif args.delete is not None:
         print(fl.deleteTest(args.delete))
+    elif args.info is not None:
+        print(fl.getTestInfo(args.info))
     elif args.get is not None:
         print(fl.getResults(args.get))
     elif args.fetch is not None:
