@@ -5,7 +5,9 @@ Copyright (c) 2020, ETH Zurich, Computer Engineering Group (TEC)
 
 import base64
 import os
+import stat
 import sys
+import time
 import requests
 import json
 import re
@@ -67,6 +69,7 @@ class Flocklab:
                     with open(flConfigPath, 'w') as f:
                         f.write('USER={}\n'.format(usr))
                         f.write('PASSWORD={}\n'.format(pwd))
+                    os.chmod(flConfigPath, stat.S_IRUSR | stat.S_IWUSR)
                     print("FlockLab authentication file successfully created!")
                 else:
                     print("ERROR: FlockLab authentication information seems wrong. No \'.flocklabauth\' file created!")
@@ -94,6 +97,24 @@ class Flocklab:
         obsList = ['{:d}'.format(e) for e in obsList]
         return ' '.join(obsList)
 
+    @staticmethod
+    def apiStr2int(apiStr):
+        '''
+        Args:
+            apiStr: string to be converted to int or None
+        Returns:
+            object of converted string (int)
+        '''
+        if apiStr is None:
+            ret = None
+        else:
+            if apiStr.isnumeric():
+                ret = int(apiStr)
+            else:
+                ret = None
+        return ret
+
+
     @staticmethod
     def getImageAsBase64(imagePath):
         '''
@@ -144,7 +165,8 @@ class Flocklab:
         Args:
             xmlPath: path to FlockLab config xml file
         Returns:
-            Result of test creation as string
+            testId: Test ID returned from flocklab if successful, None otherwise
+            info: Result of test creation as string
         '''
         creds = self.getCredentials()
 
@@ -156,16 +178,37 @@ class Flocklab:
                 'xmlfile': (os.path.basename(xmlPath), open(xmlPath, 'rb').read(), 'text/xml', {}),
             }
             req = requests.post(self.apiBaseAddr + 'newtest.php', files=files, verify=self.sslVerify)
-            # FIXME: success is not correctly detected
-            ret = re.search('<!-- cmd --><p>(Test (Id [0-9]*) successfully added.)</p>', req.text)
+            ret = re.search('<!-- cmd --><p>(Test \(Id ([0-9]*)\) successfully added.)</p>', req.text)
             if ret is not None:
-                print('success')
-                return ret.group(1)
+                info = ret.group(1)
+                testId = ret.group(2)
             else:
-                return re.search(r'<!-- cmd -->(.*)<!-- cmd -->', req.text).group(1)
+                info = re.search(r'<!-- cmd -->(.*)<!-- cmd -->', req.text).group(1)
+                testId = None
         except Exception as e:
             print(e)
-            print("Failed to contact the FlockLab API!")
+            info = 'Failed to contact the FlockLab API!'
+            testId = None
+
+        return testId, info
+
+    def createTestWithInfo(self, xmlPath):
+        '''Create a FlockLab test by using the web api and return a string with info about test start and ID
+        Args:
+            xmlPath: path to FlockLab config xml file
+        Returns:
+            info: Test ID and start date or info about failure
+        '''
+        testId, info = self.createTest(xmlPath)
+        if not testId:
+            ret = 'ERROR: Creation of test failed!\n{}'.format(info)
+        else:
+            try:
+                testinfo = self.getTestInfo(testId=testId)
+                ret = 'Test {} was successfully added and is scheduled to start at {} (local time)'.format(testId, datetime.datetime.fromtimestamp((testinfo['start_planned'])))
+            except Exception as e:
+                ret = 'Test {} was successfully added. (Test start time could not be fetched.)'.format(testId)
+        return ret
 
     def abortTest(self, testId):
         '''Abort a FlockLab test if it is running.
@@ -256,6 +299,37 @@ class Flocklab:
             print(e)
             print("Failed to contact the FlockLab API!")
 
+    def getTestInfo(self, testId):
+        '''Get information for an existing FlockLab test.
+        Args:
+            testId: ID of the test which should be delted
+        Returns:
+            Test info as a dict.
+        '''
+        creds = self.getCredentials()
+
+        # get observer list from server
+        try:
+            files = {
+                'username': (None, creds['username']),
+                'password': (None, creds['password']),
+                'q': (None, 'testinfo'),
+                'id': (None, testId),
+            }
+            req = requests.post(self.apiBaseAddr + 'api.php', files=files, verify=self.sslVerify)
+            output = json.loads(req.text)["output"]
+            # convert timestamps to int
+            output['start_planned'] = Flocklab.apiStr2int(output['start_planned'])
+            output['start'] = Flocklab.apiStr2int(output['start'])
+            output['end_planned'] = Flocklab.apiStr2int(output['end_planned'])
+            output['end'] = Flocklab.apiStr2int(output['end'])
+        except Exception as e:
+            print(e)
+            print("Failed to fetch test info from FlockLab API!")
+            output = None
+
+        return output
+
     def getObsIds(self, platform='dpp2lora'):
         '''Get currently available observer IDs (depends on user role!)
         Args:
